%% Eyeball plots
%% Latex as default text interpreter for figures
set(0,'DefaultTextInterpreter','latex')
set(groot, 'defaultAxesTickLabelInterpreter','latex'); set(groot, 'defaultLegendInterpreter','latex');
%% H band
H_intensity = intensity31 + intensity42 + intensity53 + intensity64;
K_intensity = intensity97;

lst_hours_lowres = [17 18 19 20 21 22 23 0 1 2 3 4 5 6];

%H_LST{j}(12:13)

H_eyeball_moy = zeros(15,13);
for m = 1:12
    H_intensity_m = H_intensity(month([H_time{:}]) == m);
    H_LST_m = H_LST(month([H_time{:}]) == m);
    for i = 1:length(lst_hours_lowres)
        h = lst_hours_lowres(i);
        temp_int = zeros(1, length(H_intensity));
        k = 0;
        for j = 1:length(H_intensity_m)
            %H_LST_m{j}(12:13)
            if str2double(H_LST_m{j}(12:13)) == h
                k = k + 1;
                temp_int(k) = H_intensity_m(j);
            end
        end
        temp_int = temp_int(1:k);
        H_eyeball_moy(i, m) = mean(temp_int);
    end
end

K_eyeball_moy = zeros(15,13);
for m = 1:12
    K_intensity_m = K_intensity(month([K_time{:}]) == m);
    K_LST_m = K_LST(month([K_time{:}]) == m);
    for i = 1:length(lst_hours_lowres)
        h = lst_hours_lowres(i);
        temp_int = zeros(1, length(K_intensity));
        k = 0;
        for j = 1:length(K_intensity_m)
            if str2double(K_LST_m{j}(12:13)) == h
                k = k + 1;
                temp_int(k) = K_intensity_m(j);
            end
        end
        temp_int = temp_int(1:k);
        K_eyeball_moy(i, m) = mean(temp_int);
    end
end

%% Interpolations
interp_method = 2; % 2 or 4 (or 0,2
H_eyeball_interp_full = inpaint_nans(repmat(H_eyeball_moy([1:14],[1:12]),3,3), interp_method);
H_eyeball_interp = H_eyeball_interp_full([15:29], [13:25]);
K_eyeball_interp_full = inpaint_nans(repmat(K_eyeball_moy([1:14],[1:12]),3,3), interp_method);
K_eyeball_interp = K_eyeball_interp_full([15:29], [13:25]);

%% Solar depression angle eyeball plot
eyeball_sdep_97_setting = zeros(18, 13);
eyeball_sdep_97_rising = zeros(18, 13);

for m = 1:12
    for i = 1:18
        K_sdep_setting_m = K_sdep_setting(month([K_time_setting{:}]) == m); % Temporary variables for each month
        K_sdep_rising_m = K_sdep_rising(month([K_time_rising{:}]) == m);
        intensity97_setting_m = intensity97_setting(month([K_time_setting{:}]) == m);
        intensity97_rising_m = intensity97_rising(month([K_time_rising{:}]) == m);
        
        %% Setting
        temp_int97 = zeros(1, length(K_sdep_setting_m));
        k = 0;
        for j = 1:length(K_sdep_setting_m)
            if K_sdep_setting_m(j) >= 0 + 5*(i-1) && K_sdep_setting_m(j) <= 5 + 5*(i-1)
                k = k + 1;
                temp_int97(k) = intensity97_setting_m(j);
            end
        end
        temp_int97 = temp_int97(1:k); % remove zero-tail
        
        eyeball_sdep_97_setting(i, m) = mean(temp_int97);
        clearvars k temp_int97;
        
        %% Rising
        temp_int97 = zeros(1, length(K_sdep_rising_m));
        k = 0;
        for j = 1:length(K_sdep_rising_m)
            if K_sdep_rising_m(j) >= 0 + 5*(i-1) && K_sdep_rising_m(j) <= 5 + 5*(i-1)
                k = k + 1;
                temp_int97(k) = intensity97_rising_m(j);
            end
        end
        temp_int97 = temp_int97(1:k); % remove zero-tail
        
        eyeball_sdep_97_rising(i, m) = mean(temp_int97);
        clearvars k temp_int97;
    end
end

eyeball_sdep_97 = [eyeball_sdep_97_setting; flipud(eyeball_sdep_97_rising)];

%% Solar depression angle eyeball plot
eyeball_sdep_H_setting = zeros(18, 13);
eyeball_sdep_H_rising = zeros(18, 13);

intensityH_setting = intensity31_setting + intensity42_setting + intensity53_setting + intensity64_setting;
intensityH_rising = intensity31_rising + intensity42_rising + intensity53_rising + intensity64_rising;

for m = 1:12
    for i = 1:18
        H_sdep_setting_m = H_sdep_setting(month([H_time_setting{:}]) == m); % Temporary variables for each month
        H_sdep_rising_m = H_sdep_rising(month([H_time_rising{:}]) == m);
        intensityH_setting_m = intensityH_setting(month([H_time_setting{:}]) == m);
        intensityH_rising_m = intensityH_rising(month([H_time_rising{:}]) == m);
        
        %% Setting
        temp_intH = zeros(1, length(H_sdep_setting_m));
        k = 0;
        for j = 1:length(H_sdep_setting_m)
            if H_sdep_setting_m(j) >= 0 + 5*(i-1) && H_sdep_setting_m(j) <= 5 + 5*(i-1)
                k = k + 1;
                temp_intH(k) = intensityH_setting_m(j);
            end
        end
        temp_intH = temp_intH(1:k); % remove zero-tail
        
        eyeball_sdep_H_setting(i, m) = mean(temp_intH);
        clearvars k temp_intH;
        
        %% Rising
        temp_intH = zeros(1, length(H_sdep_rising_m));
        k = 0;
        for j = 1:length(H_sdep_rising_m)
            if H_sdep_rising_m(j) >= 0 + 5*(i-1) && H_sdep_rising_m(j) <= 5 + 5*(i-1)
                k = k + 1;
                temp_intH(k) = intensityH_rising_m(j);
            end
        end
        temp_intH = temp_intH(1:k); % remove zero-tail
        
        eyeball_sdep_H_rising(i, m) = mean(temp_intH);
        clearvars k temp_intH;
    end
end

eyeball_sdep_H = [eyeball_sdep_H_setting; flipud(eyeball_sdep_H_rising)];

figure;
    pcolor(1:13, 1:15, H_eyeball_moy([1:15], [1:13]))
    fig_eye = gca;
    colormap(color_style)
    xticks([1:12] + 0.5)
    yticks([1:14] + 0.5)
    yticklabels(lst_hours_lowres)
    xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
    xlabel('Month')
    ylabel('Local solar time')
    shading('flat');
    title('H: LST resolved in hours, for each month')
    colorbar;
    %%
    set(gca,'color',[0.149019607843137 0.149019607843137 0.149019607843137], 'colormap',...
    [0.331441291040623 0 0;0.335492321823287 0 0;0.339543352605952 0 0;0.343594383388616 0 0;0.34764541417128 0 0;0.351696444953945 0 0;0.355747475736609 0 0;0.359798506519273 0 0;0.363849537301938 0 0;0.367900568084602 0 0;0.371951598867266 0 0;0.376002629649931 0 0;0.380053660432595 0 0;0.384104691215259 0 0;0.388155721997923 0 0;0.392206752780588 0 0;0.396257783563252 0 0;0.400308814345916 0 0;0.404359845128581 0 0;0.408410875911245 0 0;0.412461906693909 0 0;0.416512937476574 0 0;0.420563968259238 0 0;0.424614999041902 0 0;0.428666029824567 0 0;0.432717060607231 0 0;0.436768091389895 0 0;0.440819122172559 0 0;0.444870152955224 0 0;0.448921183737888 0 0;0.452972214520552 0 0;0.457023245303217 0 0;0.461074276085881 0 0;0.465125306868545 0 0;0.46917633765121 0 0;0.473227368433874 0 0;0.477278399216538 0 0;0.481329429999203 0 0;0.485380460781867 0 0;0.489431491564531 0 0;0.493482522347195 0 0;0.49753355312986 0 0;0.501584583912524 0 0;0.505635614695189 0 0;0.509686645477853 0 0;0.513737676260517 0 0;0.517788707043181 0 0;0.521839737825846 0 0;0.52589076860851 0 0;0.529941799391174 0 0;0.533992830173839 0 0;0.538043860956503 0 0;0.542094891739167 0 0;0.546145922521832 0 0;0.550196953304496 0 0;0.55424798408716 0 0;0.558299014869825 0 0;0.562350045652489 0 0;0.566401076435153 0 0;0.570452107217818 0 0;0.574503138000482 0 0;0.578554168783146 0 0;0.582605199565811 0 0;0.586656230348475 0 0;0.59070726113114 0 0;0.594758291913804 0 0;0.598809322696469 0 0;0.602860353479133 0 0;0.606911384261798 0 0;0.610962415044462 0 0;0.615013445827126 0 0;0.619064476609791 0 0;0.623115507392455 0 0;0.62716653817512 0 0;0.631217568957784 0 0;0.635268599740449 0 0;0.639319630523113 0 0;0.643370661305777 0 0;0.647421692088442 0 0;0.651472722871106 0 0;0.655523753653771 0 0;0.659574784436435 0 0;0.6636258152191 0 0;0.667676846001764 0 0;0.671727876784428 0 0;0.675778907567093 0 0;0.679829938349757 0 0;0.683880969132422 0 0;0.687931999915086 0 0;0.691983030697751 0 0;0.696034061480415 0 0;0.70008509226308 0 0;0.704136123045744 0 0;0.708187153828408 0 0;0.712238184611073 0 0;0.716289215393737 0 0;0.720340246176402 0 0;0.724391276959066 0 0;0.728442307741731 0 0;0.732493338524395 0 0;0.736544369307059 0 0;0.740595400089724 0 0;0.744646430872388 0 0;0.748697461655053 0 0;0.752748492437717 0 0;0.756799523220381 0 0;0.760850554003046 0 0;0.76490158478571 0 0;0.768952615568375 0 0;0.773003646351039 0 0;0.777054677133704 0 0;0.781105707916368 0 0;0.785156738699033 0 0;0.789207769481697 0 0;0.793258800264361 0 0;0.797309831047026 0 0;0.80136086182969 0 0;0.805411892612355 0 0;0.809462923395019 0 0;0.813513954177684 0 0;0.817564984960348 0 0;0.821616015743012 0 0;0.825667046525677 0 0;0.829718077308341 0 0;0.833769108091006 0 0;0.83782013887367 0 0;0.841871169656334 0 0;0.845922200438999 0 0;0.849973231221663 0 0;0.854024262004328 0 0;0.858075292786992 0 0;0.862126323569656 0 0;0.866177354352321 0 0;0.870228385134985 0 0;0.874279415917649 0 0;0.878330446700314 0 0;0.882381477482978 0 0;0.886432508265642 0 0;0.890483539048307 0 0;0.894534569830971 0 0;0.898585600613636 0 0;0.9026366313963 0 0;0.906687662178964 0 0;0.910738692961629 0 0;0.914789723744293 0 0;0.918840754526957 0 0;0.922891785309622 0 0;0.926942816092286 0 0;0.930993846874951 0 0;0.935044877657615 0 0;0.939095908440279 0 0;0.943146939222944 0 0;0.947197970005608 0 0;0.951249000788272 0 0;0.955300031570937 0 0;0.959351062353601 0 0;0.963402093136266 0 0;0.96745312391893 0 0;0.971504154701594 0 0;0.975555185484259 0 0;0.979606216266923 0 0;0.983657247049588 0 0;0.987708277832252 0 0;0.991759308614916 0 0;0.995806899951635 3.43944594599642e-06 0;0.998789593369118 0.00107177681112655 0;0.999865498621048 0.00404690234186127 0;0.99999802076514 0.00796541098043363 0;1 0.0120144625282381 0;1 0.0160654933109025 0;1 0.0201165240935669 0;1 0.0241675548762312 0;1 0.0282185856588956 0;1 0.03226961644156 0;1 0.0363206472242244 0;1 0.0403716780068887 0;1 0.0444227087895531 0;1 0.0484737395722175 0;1 0.0525247703548819 0;1 0.0565758011375462 0;1 0.0606268319202106 0;1 0.064677862702875 0;1 0.0687288934855394 0;1 0.0727799242682037 0;1 0.0768309550508681 0;1 0.0808819858335325 0;1 0.0849330166161969 0;1 0.0889840473988612 0;1 0.0930350781815256 0;1 0.09708610896419 0;1 0.101137139746854 0;1 0.105188170529519 0;1 0.109239201312183 0;1 0.113290232094847 0;1 0.117341262877512 0;1 0.121392293660176 0;1 0.125443324442841 0;1 0.129494355225505 0;1 0.133545386008169 0;1 0.137596416790834 0;1 0.141647447573498 0;1 0.145698478356162 0;1 0.149749509138827 0;1 0.153800539921491 0;1 0.157851570704155 0;1 0.16190260148682 0;1 0.165953632269484 0;1 0.170004663052149 0;1 0.174055693834813 0;1 0.178106724617477 0;1 0.182157755400142 0;1 0.186208786182806 0;1 0.19025981696547 0;1 0.194310847748135 0;1 0.198361878530799 0;1 0.202412909313464 0;1 0.206463940096128 0;1 0.210514970878792 0;1 0.214566001661457 0;1 0.218617032444121 0;1 0.222668063226785 0;1 0.22671909400945 0;1 0.230770124792114 0;1 0.234821155574779 0;1 0.238872186357443 0;1 0.242923217140107 0;1 0.246974247922772 0;1 0.251025278705436 0;1 0.2550763094881 0;1 0.259127340270765 0;1 0.263178371053429 0;1 0.267229401836094 0;1 0.271280432618758 0;1 0.275331463401422 0;1 0.279382494184087 0;1 0.283433524966751 0;1 0.287484555749415 0;1 0.29153558653208 0;1 0.295586617314744 0;1 0.299637648097408 0;1 0.303688678880073 0;1 0.307739709662737 0;1 0.311790740445401 0;1 0.315841771228065 0;1 0.31989280201073 0;1 0.323943832793394 0;1 0.327994863576058 0;1 0.332045894358722 0;1 0.336096925141387 0;1 0.340147955924051 0;1 0.344198986706715 0;1 0.348250017489379 0;1 0.352301048272044 0;1 0.356352079054708 0;1 0.360403109837372 0;1 0.364454140620036 0;1 0.368505171402701 0;1 0.372556202185365 0;1 0.376607232968029 0;1 0.380658263750694 0;1 0.384709294533358 0;1 0.388760325316022 0;1 0.392811356098686 0;1 0.396862386881351 0;1 0.400913417664015 0;1 0.404964448446679 0;1 0.409015479229343 0;1 0.413066510012008 0;1 0.417117540794672 0;1 0.421168571577336 0;1 0.42521960236 0;1 0.429270633142665 0;1 0.433321663925329 0;1 0.437372694707993 0;1 0.441423725490657 0;1 0.445474756273322 0;1 0.449525787055986 0;1 0.45357681783865 0;1 0.457627848621314 0;1 0.461678879403979 0;1 0.465729910186643 0;1 0.469780940969307 0;1 0.473831971751971 0;1 0.477883002534636 0;1 0.4819340333173 0;1 0.485985064099964 0;1 0.490036094882628 0;1 0.494087125665293 0;1 0.498138156447957 0;1 0.502189187230621 0;1 0.506240218013285 0;1 0.51029124879595 0;1 0.514342279578614 0;1 0.518393310361278 0;1 0.522444341143942 0;1 0.526495371926607 0;1 0.530546402709271 0;1 0.534597433491935 0;1 0.5386484642746 0;1 0.542699495057264 0;1 0.546750525839928 0;1 0.550801556622592 0;1 0.554852587405257 0;1 0.558903618187921 0;1 0.562954648970585 0;1 0.567005679753249 0;1 0.571056710535913 0;1 0.575107741318578 0;1 0.579158772101242 0;1 0.583209802883906 0;1 0.587260833666571 0;1 0.591311864449235 0;1 0.595362895231899 0;1 0.599413926014563 0;1 0.603464956797228 0;1 0.607515987579892 0;1 0.611567018362556 0;1 0.61561804914522 0;1 0.619669079927885 0;1 0.623720110710549 0;1 0.627771141493213 0;1 0.631822172275877 0;1 0.635873203058542 0;1 0.639924233841206 0;1 0.64397526462387 0;1 0.648026295406534 0;1 0.652077326189199 0;1 0.656128356971863 0;1 0.660179387754527 0;1 0.664230418537191 0;1 0.668281449319856 0;1 0.67233248010252 0;1 0.676383510885184 0;1 0.680434541667849 0;1 0.684485572450513 0;1 0.688536603233177 0;1 0.692587634015841 0;1 0.696638664798506 0;1 0.70068969558117 0;1 0.704740726363834 0;1 0.708791757146498 0;1 0.713023839584252 0;1 0.716653820006239 0;1 0.720283800428227 0;1 0.723913780850214 0;1 0.727543761272201 0;1 0.731173741694188 0;1 0.734803722116176 0;1 0.738433702538163 0;1 0.74206368296015 0;1 0.745693663382137 0;1 0.749323643804125 0;1 0.752953624226112 0;1 0.756583604648099 0;1 0.760213585070086 0;1 0.763843565492073 0;1 0.767473545914061 0;1 0.771103526336048 0;1 0.774733506758035 0;1 0.778363487180022 0;1 0.78199346760201 0;1 0.785623448023997 0;1 0.789253428445984 0;1 0.792883408867971 0;1 0.796513389289959 0;1 0.800143369711946 0;1 0.803773350133933 0;1 0.80740333055592 0;1 0.811033310977908 0;1 0.814663291399895 0;1 0.818293271821882 0;1 0.821923252243869 0;1 0.825553232665856 0;1 0.829183213087844 0;1 0.832813193509831 0;1 0.836443173931818 0;1 0.840073154353805 0;1 0.843703134775793 0;1 0.84733311519778 0;1 0.850963095619767 0;1 0.854593076041754 0;1 0.858223056463742 0;1 0.861853036885729 0;1 0.865483017307716 0;1 0.869112997729703 0;1 0.872742978151691 0;1 0.876372958573678 0;1 0.880002938995665 0;1 0.883632919417652 0;1 0.887262899839639 0;1 0.890892880261627 0;1 0.894522860683614 0;1 0.898152841105601 0;1 0.901782821527588 0;1 0.905412801949576 0;1 0.909042782371563 0;1 0.91267276279355 0;1 0.916302743215537 0;1 0.919932723637525 0;1 0.923562704059512 0;1 0.927192684481499 0;1 0.930822664903486 0;1 0.934452645325474 0;1 0.938082625747461 0;1 0.941712606169448 0;1 0.945342586591435 0;1 0.948972567013423 0;1 0.95260254743541 0;1 0.956232527857397 0;1 0.959862508279384 0;1 0.963492488701371 0;1 0.967122469123359 0;1 0.970752449545346 0;1 0.974382429967333 0;1 0.97801241038932 0;1 0.981642390811308 0;1 0.985272371233295 0;1 0.988902351655282 0;1 0.992532218487635 1.7038445099368e-07;1 0.996157817343127 6.74273419432007e-06;1 0.999439815419274 0.000528716252954609;1 0.999997903876187 0.00513655420056591;1 0.999999949287327 0.0105784567168368;1 1 0.0160233512808084;1 1 0.0214683219137892;1 1 0.0269132925467701;1 1 0.0323582631797509;1 1 0.0378032338127318;1 1 0.0432482044457126;1 1 0.0486931750786935;1 1 0.0541381457116744;1 1 0.0595831163446552;1 1 0.0650280869776361;1 1 0.0704730576106169;1 1 0.0759180282435978;1 1 0.0813629988765786;1 1 0.0868079695095595;1 1 0.0922529401425403;1 1 0.0976979107755212;1 1 0.103142881408502;1 1 0.108587852041483;1 1 0.114032822674464;1 1 0.119477793307445;1 1 0.124922763940425;1 1 0.130367734573406;1 1 0.135812705206387;1 1 0.141257675839368;1 1 0.146702646472349;1 1 0.15214761710533;1 1 0.157592587738311;1 1 0.163037558371291;1 1 0.168482529004272;1 1 0.173927499637253;1 1 0.179372470270234;1 1 0.184817440903215;1 1 0.190262411536196;1 1 0.195707382169177;1 1 0.201152352802157;1 1 0.206597323435138;1 1 0.212042294068119;1 1 0.2174872647011;1 1 0.222932235334081;1 1 0.228377205967062;1 1 0.233822176600043;1 1 0.239267147233023;1 1 0.244712117866004;1 1 0.250157088498985;1 1 0.255602059131966;1 1 0.261047029764947;1 1 0.266492000397928;1 1 0.271936971030909;1 1 0.277381941663889;1 1 0.28282691229687;1 1 0.288271882929851;1 1 0.293716853562832;1 1 0.299161824195813;1 1 0.304606794828794;1 1 0.310051765461775;1 1 0.315496736094755;1 1 0.320941706727736;1 1 0.326386677360717;1 1 0.331831647993698;1 1 0.337276618626679;1 1 0.34272158925966;1 1 0.348166559892641;1 1 0.353611530525621;1 1 0.359056501158602;1 1 0.364501471791583;1 1 0.369946442424564;1 1 0.375391413057545;1 1 0.380836383690526;1 1 0.386281354323507;1 1 0.391726324956487;1 1 0.397171295589468;1 1 0.402616266222449;1 1 0.40806123685543;1 1 0.413506207488411;1 1 0.418951178121391;1 1 0.424396148754372;1 1 0.429841119387353;1 1 0.435286090020334;1 1 0.440731060653315;1 1 0.446176031286296;1 1 0.451621001919276;1 1 0.457065972552257;1 1 0.462510943185238;1 1 0.467955913818219;1 1 0.4734008844512;1 1 0.478845855084181;1 1 0.484290825717162;1 1 0.489735796350143;1 1 0.495180766983124;1 1 0.500625737616106;1 1 0.506070708249087;1 1 0.511515678882068;1 1 0.516960649515049;1 1 0.52240562014803;1 1 0.527850590781012;1 1 0.533295561413993;1 1 0.538740532046974;1 1 0.544185502679955;1 1 0.549630473312936;1 1 0.555075443945917;1 1 0.560520414578899;1 1 0.56596538521188;1 1 0.571410355844861;1 1 0.576855326477842;1 1 0.582300297110823;1 1 0.587745267743804;1 1 0.593190238376786;1 1 0.598635209009767;1 1 0.604080179642748;1 1 0.609525150275729;1 1 0.61497012090871;1 1 0.620415091541691;1 1 0.625860062174673;1 1 0.631305032807654;1 1 0.636750003440635;1 1 0.642194974073616;1 1 0.647639944706597;1 1 0.653084915339579;1 1 0.658504314154768;1 1 0.664186626681104;1 1 0.67007808937091;1 1 0.675969552060716;1 1 0.681861014750521;1 1 0.687752477440327;1 1 0.693643940130133;1 1 0.699535402819939;1 1 0.705426865509745;1 1 0.711318328199551;1 1 0.717209790889357;1 1 0.723101253579163;1 1 0.728992716268969;1 1 0.734884178958775;1 1 0.740775641648581;1 1 0.746667104338387;1 1 0.752558567028193;1 1 0.758450029717999;1 1 0.764341492407805;1 1 0.770232955097611;1 1 0.776124417787416;1 1 0.782015880477222;1 1 0.787907343167028;1 1 0.793798805856834;1 1 0.79969026854664;1 1 0.805581731236446;1 1 0.811473193926252;1 1 0.817364656616058;1 1 0.823256119305864;1 1 0.82914758199567;1 1 0.835039044685476;1 1 0.840930507375282;1 1 0.846821970065088;1 1 0.852713432754894;1 1 0.8586048954447;1 1 0.864496358134506;1 1 0.870387820824312;1 1 0.876279283514118;1 1 0.882170746203923;1 1 0.888062208893729;1 1 0.893953671583535;1 1 0.899845134273341;1 1 0.905736596963147;1 1 0.911628059652953;1 1 0.917519522342759;1 1 0.923410985032565;1 1 0.929302447722371;1 1 0.935193910412177;1 1 0.941085373101983;1 1 0.946976835791789;1 1 0.952868298481595;1 1 0.958759761171401;1 1 0.964651223861207;1 1 0.970542686551013;1 1 0.976434149240818;1 1 0.982325611930624;1 1 0.98821707462043;1 1 0.994108537310233;1 1 0.999999999999974])
    annotation('rectangle',...
    [0.829166666666665 0.0458253968253974 0.0416666666666672 0.0383015873015867],...
    'FaceColor',[0.149019607843137 0.149019607843137 0.149019607843137]);
    annotation('textbox',...
    [0.869047619047619 0.022809523809524 0.0875000000000002 0.0650793650793651],...
    'String',{'NaN'},...
    'LineStyle','none',...
    'Interpreter','latex',...
    'FitBoxToText','off');

figure;
    pcolor(1:13, 1:15, K_eyeball_moy([1:15], [1:13]))
    fig_eye = gca;
    colormap(color_style)
    xticks([1:12] + 0.5)
    yticks([1:14] + 0.5)
    yticklabels(lst_hours_lowres)
    xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
    xlabel('Month')
    ylabel('Local solar time')
    shading('flat');
    title('K: LST resolved in hours, for each month')
    colorbar;
    %%
    set(gca,'color',[0.149019607843137 0.149019607843137 0.149019607843137], 'colormap',...
    [0.331441291040623 0 0;0.335492321823287 0 0;0.339543352605952 0 0;0.343594383388616 0 0;0.34764541417128 0 0;0.351696444953945 0 0;0.355747475736609 0 0;0.359798506519273 0 0;0.363849537301938 0 0;0.367900568084602 0 0;0.371951598867266 0 0;0.376002629649931 0 0;0.380053660432595 0 0;0.384104691215259 0 0;0.388155721997923 0 0;0.392206752780588 0 0;0.396257783563252 0 0;0.400308814345916 0 0;0.404359845128581 0 0;0.408410875911245 0 0;0.412461906693909 0 0;0.416512937476574 0 0;0.420563968259238 0 0;0.424614999041902 0 0;0.428666029824567 0 0;0.432717060607231 0 0;0.436768091389895 0 0;0.440819122172559 0 0;0.444870152955224 0 0;0.448921183737888 0 0;0.452972214520552 0 0;0.457023245303217 0 0;0.461074276085881 0 0;0.465125306868545 0 0;0.46917633765121 0 0;0.473227368433874 0 0;0.477278399216538 0 0;0.481329429999203 0 0;0.485380460781867 0 0;0.489431491564531 0 0;0.493482522347195 0 0;0.49753355312986 0 0;0.501584583912524 0 0;0.505635614695189 0 0;0.509686645477853 0 0;0.513737676260517 0 0;0.517788707043181 0 0;0.521839737825846 0 0;0.52589076860851 0 0;0.529941799391174 0 0;0.533992830173839 0 0;0.538043860956503 0 0;0.542094891739167 0 0;0.546145922521832 0 0;0.550196953304496 0 0;0.55424798408716 0 0;0.558299014869825 0 0;0.562350045652489 0 0;0.566401076435153 0 0;0.570452107217818 0 0;0.574503138000482 0 0;0.578554168783146 0 0;0.582605199565811 0 0;0.586656230348475 0 0;0.59070726113114 0 0;0.594758291913804 0 0;0.598809322696469 0 0;0.602860353479133 0 0;0.606911384261798 0 0;0.610962415044462 0 0;0.615013445827126 0 0;0.619064476609791 0 0;0.623115507392455 0 0;0.62716653817512 0 0;0.631217568957784 0 0;0.635268599740449 0 0;0.639319630523113 0 0;0.643370661305777 0 0;0.647421692088442 0 0;0.651472722871106 0 0;0.655523753653771 0 0;0.659574784436435 0 0;0.6636258152191 0 0;0.667676846001764 0 0;0.671727876784428 0 0;0.675778907567093 0 0;0.679829938349757 0 0;0.683880969132422 0 0;0.687931999915086 0 0;0.691983030697751 0 0;0.696034061480415 0 0;0.70008509226308 0 0;0.704136123045744 0 0;0.708187153828408 0 0;0.712238184611073 0 0;0.716289215393737 0 0;0.720340246176402 0 0;0.724391276959066 0 0;0.728442307741731 0 0;0.732493338524395 0 0;0.736544369307059 0 0;0.740595400089724 0 0;0.744646430872388 0 0;0.748697461655053 0 0;0.752748492437717 0 0;0.756799523220381 0 0;0.760850554003046 0 0;0.76490158478571 0 0;0.768952615568375 0 0;0.773003646351039 0 0;0.777054677133704 0 0;0.781105707916368 0 0;0.785156738699033 0 0;0.789207769481697 0 0;0.793258800264361 0 0;0.797309831047026 0 0;0.80136086182969 0 0;0.805411892612355 0 0;0.809462923395019 0 0;0.813513954177684 0 0;0.817564984960348 0 0;0.821616015743012 0 0;0.825667046525677 0 0;0.829718077308341 0 0;0.833769108091006 0 0;0.83782013887367 0 0;0.841871169656334 0 0;0.845922200438999 0 0;0.849973231221663 0 0;0.854024262004328 0 0;0.858075292786992 0 0;0.862126323569656 0 0;0.866177354352321 0 0;0.870228385134985 0 0;0.874279415917649 0 0;0.878330446700314 0 0;0.882381477482978 0 0;0.886432508265642 0 0;0.890483539048307 0 0;0.894534569830971 0 0;0.898585600613636 0 0;0.9026366313963 0 0;0.906687662178964 0 0;0.910738692961629 0 0;0.914789723744293 0 0;0.918840754526957 0 0;0.922891785309622 0 0;0.926942816092286 0 0;0.930993846874951 0 0;0.935044877657615 0 0;0.939095908440279 0 0;0.943146939222944 0 0;0.947197970005608 0 0;0.951249000788272 0 0;0.955300031570937 0 0;0.959351062353601 0 0;0.963402093136266 0 0;0.96745312391893 0 0;0.971504154701594 0 0;0.975555185484259 0 0;0.979606216266923 0 0;0.983657247049588 0 0;0.987708277832252 0 0;0.991759308614916 0 0;0.995806899951635 3.43944594599642e-06 0;0.998789593369118 0.00107177681112655 0;0.999865498621048 0.00404690234186127 0;0.99999802076514 0.00796541098043363 0;1 0.0120144625282381 0;1 0.0160654933109025 0;1 0.0201165240935669 0;1 0.0241675548762312 0;1 0.0282185856588956 0;1 0.03226961644156 0;1 0.0363206472242244 0;1 0.0403716780068887 0;1 0.0444227087895531 0;1 0.0484737395722175 0;1 0.0525247703548819 0;1 0.0565758011375462 0;1 0.0606268319202106 0;1 0.064677862702875 0;1 0.0687288934855394 0;1 0.0727799242682037 0;1 0.0768309550508681 0;1 0.0808819858335325 0;1 0.0849330166161969 0;1 0.0889840473988612 0;1 0.0930350781815256 0;1 0.09708610896419 0;1 0.101137139746854 0;1 0.105188170529519 0;1 0.109239201312183 0;1 0.113290232094847 0;1 0.117341262877512 0;1 0.121392293660176 0;1 0.125443324442841 0;1 0.129494355225505 0;1 0.133545386008169 0;1 0.137596416790834 0;1 0.141647447573498 0;1 0.145698478356162 0;1 0.149749509138827 0;1 0.153800539921491 0;1 0.157851570704155 0;1 0.16190260148682 0;1 0.165953632269484 0;1 0.170004663052149 0;1 0.174055693834813 0;1 0.178106724617477 0;1 0.182157755400142 0;1 0.186208786182806 0;1 0.19025981696547 0;1 0.194310847748135 0;1 0.198361878530799 0;1 0.202412909313464 0;1 0.206463940096128 0;1 0.210514970878792 0;1 0.214566001661457 0;1 0.218617032444121 0;1 0.222668063226785 0;1 0.22671909400945 0;1 0.230770124792114 0;1 0.234821155574779 0;1 0.238872186357443 0;1 0.242923217140107 0;1 0.246974247922772 0;1 0.251025278705436 0;1 0.2550763094881 0;1 0.259127340270765 0;1 0.263178371053429 0;1 0.267229401836094 0;1 0.271280432618758 0;1 0.275331463401422 0;1 0.279382494184087 0;1 0.283433524966751 0;1 0.287484555749415 0;1 0.29153558653208 0;1 0.295586617314744 0;1 0.299637648097408 0;1 0.303688678880073 0;1 0.307739709662737 0;1 0.311790740445401 0;1 0.315841771228065 0;1 0.31989280201073 0;1 0.323943832793394 0;1 0.327994863576058 0;1 0.332045894358722 0;1 0.336096925141387 0;1 0.340147955924051 0;1 0.344198986706715 0;1 0.348250017489379 0;1 0.352301048272044 0;1 0.356352079054708 0;1 0.360403109837372 0;1 0.364454140620036 0;1 0.368505171402701 0;1 0.372556202185365 0;1 0.376607232968029 0;1 0.380658263750694 0;1 0.384709294533358 0;1 0.388760325316022 0;1 0.392811356098686 0;1 0.396862386881351 0;1 0.400913417664015 0;1 0.404964448446679 0;1 0.409015479229343 0;1 0.413066510012008 0;1 0.417117540794672 0;1 0.421168571577336 0;1 0.42521960236 0;1 0.429270633142665 0;1 0.433321663925329 0;1 0.437372694707993 0;1 0.441423725490657 0;1 0.445474756273322 0;1 0.449525787055986 0;1 0.45357681783865 0;1 0.457627848621314 0;1 0.461678879403979 0;1 0.465729910186643 0;1 0.469780940969307 0;1 0.473831971751971 0;1 0.477883002534636 0;1 0.4819340333173 0;1 0.485985064099964 0;1 0.490036094882628 0;1 0.494087125665293 0;1 0.498138156447957 0;1 0.502189187230621 0;1 0.506240218013285 0;1 0.51029124879595 0;1 0.514342279578614 0;1 0.518393310361278 0;1 0.522444341143942 0;1 0.526495371926607 0;1 0.530546402709271 0;1 0.534597433491935 0;1 0.5386484642746 0;1 0.542699495057264 0;1 0.546750525839928 0;1 0.550801556622592 0;1 0.554852587405257 0;1 0.558903618187921 0;1 0.562954648970585 0;1 0.567005679753249 0;1 0.571056710535913 0;1 0.575107741318578 0;1 0.579158772101242 0;1 0.583209802883906 0;1 0.587260833666571 0;1 0.591311864449235 0;1 0.595362895231899 0;1 0.599413926014563 0;1 0.603464956797228 0;1 0.607515987579892 0;1 0.611567018362556 0;1 0.61561804914522 0;1 0.619669079927885 0;1 0.623720110710549 0;1 0.627771141493213 0;1 0.631822172275877 0;1 0.635873203058542 0;1 0.639924233841206 0;1 0.64397526462387 0;1 0.648026295406534 0;1 0.652077326189199 0;1 0.656128356971863 0;1 0.660179387754527 0;1 0.664230418537191 0;1 0.668281449319856 0;1 0.67233248010252 0;1 0.676383510885184 0;1 0.680434541667849 0;1 0.684485572450513 0;1 0.688536603233177 0;1 0.692587634015841 0;1 0.696638664798506 0;1 0.70068969558117 0;1 0.704740726363834 0;1 0.708791757146498 0;1 0.713023839584252 0;1 0.716653820006239 0;1 0.720283800428227 0;1 0.723913780850214 0;1 0.727543761272201 0;1 0.731173741694188 0;1 0.734803722116176 0;1 0.738433702538163 0;1 0.74206368296015 0;1 0.745693663382137 0;1 0.749323643804125 0;1 0.752953624226112 0;1 0.756583604648099 0;1 0.760213585070086 0;1 0.763843565492073 0;1 0.767473545914061 0;1 0.771103526336048 0;1 0.774733506758035 0;1 0.778363487180022 0;1 0.78199346760201 0;1 0.785623448023997 0;1 0.789253428445984 0;1 0.792883408867971 0;1 0.796513389289959 0;1 0.800143369711946 0;1 0.803773350133933 0;1 0.80740333055592 0;1 0.811033310977908 0;1 0.814663291399895 0;1 0.818293271821882 0;1 0.821923252243869 0;1 0.825553232665856 0;1 0.829183213087844 0;1 0.832813193509831 0;1 0.836443173931818 0;1 0.840073154353805 0;1 0.843703134775793 0;1 0.84733311519778 0;1 0.850963095619767 0;1 0.854593076041754 0;1 0.858223056463742 0;1 0.861853036885729 0;1 0.865483017307716 0;1 0.869112997729703 0;1 0.872742978151691 0;1 0.876372958573678 0;1 0.880002938995665 0;1 0.883632919417652 0;1 0.887262899839639 0;1 0.890892880261627 0;1 0.894522860683614 0;1 0.898152841105601 0;1 0.901782821527588 0;1 0.905412801949576 0;1 0.909042782371563 0;1 0.91267276279355 0;1 0.916302743215537 0;1 0.919932723637525 0;1 0.923562704059512 0;1 0.927192684481499 0;1 0.930822664903486 0;1 0.934452645325474 0;1 0.938082625747461 0;1 0.941712606169448 0;1 0.945342586591435 0;1 0.948972567013423 0;1 0.95260254743541 0;1 0.956232527857397 0;1 0.959862508279384 0;1 0.963492488701371 0;1 0.967122469123359 0;1 0.970752449545346 0;1 0.974382429967333 0;1 0.97801241038932 0;1 0.981642390811308 0;1 0.985272371233295 0;1 0.988902351655282 0;1 0.992532218487635 1.7038445099368e-07;1 0.996157817343127 6.74273419432007e-06;1 0.999439815419274 0.000528716252954609;1 0.999997903876187 0.00513655420056591;1 0.999999949287327 0.0105784567168368;1 1 0.0160233512808084;1 1 0.0214683219137892;1 1 0.0269132925467701;1 1 0.0323582631797509;1 1 0.0378032338127318;1 1 0.0432482044457126;1 1 0.0486931750786935;1 1 0.0541381457116744;1 1 0.0595831163446552;1 1 0.0650280869776361;1 1 0.0704730576106169;1 1 0.0759180282435978;1 1 0.0813629988765786;1 1 0.0868079695095595;1 1 0.0922529401425403;1 1 0.0976979107755212;1 1 0.103142881408502;1 1 0.108587852041483;1 1 0.114032822674464;1 1 0.119477793307445;1 1 0.124922763940425;1 1 0.130367734573406;1 1 0.135812705206387;1 1 0.141257675839368;1 1 0.146702646472349;1 1 0.15214761710533;1 1 0.157592587738311;1 1 0.163037558371291;1 1 0.168482529004272;1 1 0.173927499637253;1 1 0.179372470270234;1 1 0.184817440903215;1 1 0.190262411536196;1 1 0.195707382169177;1 1 0.201152352802157;1 1 0.206597323435138;1 1 0.212042294068119;1 1 0.2174872647011;1 1 0.222932235334081;1 1 0.228377205967062;1 1 0.233822176600043;1 1 0.239267147233023;1 1 0.244712117866004;1 1 0.250157088498985;1 1 0.255602059131966;1 1 0.261047029764947;1 1 0.266492000397928;1 1 0.271936971030909;1 1 0.277381941663889;1 1 0.28282691229687;1 1 0.288271882929851;1 1 0.293716853562832;1 1 0.299161824195813;1 1 0.304606794828794;1 1 0.310051765461775;1 1 0.315496736094755;1 1 0.320941706727736;1 1 0.326386677360717;1 1 0.331831647993698;1 1 0.337276618626679;1 1 0.34272158925966;1 1 0.348166559892641;1 1 0.353611530525621;1 1 0.359056501158602;1 1 0.364501471791583;1 1 0.369946442424564;1 1 0.375391413057545;1 1 0.380836383690526;1 1 0.386281354323507;1 1 0.391726324956487;1 1 0.397171295589468;1 1 0.402616266222449;1 1 0.40806123685543;1 1 0.413506207488411;1 1 0.418951178121391;1 1 0.424396148754372;1 1 0.429841119387353;1 1 0.435286090020334;1 1 0.440731060653315;1 1 0.446176031286296;1 1 0.451621001919276;1 1 0.457065972552257;1 1 0.462510943185238;1 1 0.467955913818219;1 1 0.4734008844512;1 1 0.478845855084181;1 1 0.484290825717162;1 1 0.489735796350143;1 1 0.495180766983124;1 1 0.500625737616106;1 1 0.506070708249087;1 1 0.511515678882068;1 1 0.516960649515049;1 1 0.52240562014803;1 1 0.527850590781012;1 1 0.533295561413993;1 1 0.538740532046974;1 1 0.544185502679955;1 1 0.549630473312936;1 1 0.555075443945917;1 1 0.560520414578899;1 1 0.56596538521188;1 1 0.571410355844861;1 1 0.576855326477842;1 1 0.582300297110823;1 1 0.587745267743804;1 1 0.593190238376786;1 1 0.598635209009767;1 1 0.604080179642748;1 1 0.609525150275729;1 1 0.61497012090871;1 1 0.620415091541691;1 1 0.625860062174673;1 1 0.631305032807654;1 1 0.636750003440635;1 1 0.642194974073616;1 1 0.647639944706597;1 1 0.653084915339579;1 1 0.658504314154768;1 1 0.664186626681104;1 1 0.67007808937091;1 1 0.675969552060716;1 1 0.681861014750521;1 1 0.687752477440327;1 1 0.693643940130133;1 1 0.699535402819939;1 1 0.705426865509745;1 1 0.711318328199551;1 1 0.717209790889357;1 1 0.723101253579163;1 1 0.728992716268969;1 1 0.734884178958775;1 1 0.740775641648581;1 1 0.746667104338387;1 1 0.752558567028193;1 1 0.758450029717999;1 1 0.764341492407805;1 1 0.770232955097611;1 1 0.776124417787416;1 1 0.782015880477222;1 1 0.787907343167028;1 1 0.793798805856834;1 1 0.79969026854664;1 1 0.805581731236446;1 1 0.811473193926252;1 1 0.817364656616058;1 1 0.823256119305864;1 1 0.82914758199567;1 1 0.835039044685476;1 1 0.840930507375282;1 1 0.846821970065088;1 1 0.852713432754894;1 1 0.8586048954447;1 1 0.864496358134506;1 1 0.870387820824312;1 1 0.876279283514118;1 1 0.882170746203923;1 1 0.888062208893729;1 1 0.893953671583535;1 1 0.899845134273341;1 1 0.905736596963147;1 1 0.911628059652953;1 1 0.917519522342759;1 1 0.923410985032565;1 1 0.929302447722371;1 1 0.935193910412177;1 1 0.941085373101983;1 1 0.946976835791789;1 1 0.952868298481595;1 1 0.958759761171401;1 1 0.964651223861207;1 1 0.970542686551013;1 1 0.976434149240818;1 1 0.982325611930624;1 1 0.98821707462043;1 1 0.994108537310233;1 1 0.999999999999974])
    annotation('rectangle',...
    [0.829166666666665 0.0458253968253974 0.0416666666666672 0.0383015873015867],...
    'FaceColor',[0.149019607843137 0.149019607843137 0.149019607843137]);
    annotation('textbox',...
    [0.869047619047619 0.022809523809524 0.0875000000000002 0.0650793650793651],...
    'String',{'NaN'},...
    'LineStyle','none',...
    'Interpreter','latex',...
    'FitBoxToText','off');

    figure;
    contourf(H_eyeball_interp, 25, 'linestyle','none')
    fig_eye_lst_lowres = gca;
    colormap('Hot(1200)')
    xticks([1:12] + 0.5)
    yticks([1:14] + 0.5)
    yticklabels(lst_hours_lowres)
    xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
    xlabel('Month')
    ylabel('local solar time')
    shading(shade_style);
    title('H: lst. lowres. 97. interp.')
    colorbar;
    
    figure;
    contourf(K_eyeball_interp, 25, 'linestyle','none')
    fig_eye_lst_lowres = gca;
    colormap('Hot(1200)')
    xticks([1:12] + 0.5)
    yticks([1:14] + 0.5)
    yticklabels(lst_hours_lowres)
    xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
    xlabel('Month')
    ylabel('local solar time')
    shading(shade_style);
    title('K: lst. lowres. 97. interp.')
    colorbar;

    figure;
        h = pcolor(1:13, (0:5:175), eyeball_sdep_97);%, 50, 'linecolor', 'none');
        shading flat;
        colormap('Hot(1200)')
        set(h,'alphadata',~isnan(eyeball_sdep_97))
        set(gca,'color',[0.15,0.15,0.15]) 
        xticks([1:12] + 0.5)
        yticks([0:10:180])
        yticklabels([0:10:90 80:-10:0])
        xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
        xlabel('Month')
        ylabel('Solar depression angle [degrees]')
        title('Solar depression angle. 97. Time increasing upwards.')
        colorbar;
            %%
    set(gca,'color',[0.149019607843137 0.149019607843137 0.149019607843137], 'colormap',...
    [0.331441291040623 0 0;0.335492321823287 0 0;0.339543352605952 0 0;0.343594383388616 0 0;0.34764541417128 0 0;0.351696444953945 0 0;0.355747475736609 0 0;0.359798506519273 0 0;0.363849537301938 0 0;0.367900568084602 0 0;0.371951598867266 0 0;0.376002629649931 0 0;0.380053660432595 0 0;0.384104691215259 0 0;0.388155721997923 0 0;0.392206752780588 0 0;0.396257783563252 0 0;0.400308814345916 0 0;0.404359845128581 0 0;0.408410875911245 0 0;0.412461906693909 0 0;0.416512937476574 0 0;0.420563968259238 0 0;0.424614999041902 0 0;0.428666029824567 0 0;0.432717060607231 0 0;0.436768091389895 0 0;0.440819122172559 0 0;0.444870152955224 0 0;0.448921183737888 0 0;0.452972214520552 0 0;0.457023245303217 0 0;0.461074276085881 0 0;0.465125306868545 0 0;0.46917633765121 0 0;0.473227368433874 0 0;0.477278399216538 0 0;0.481329429999203 0 0;0.485380460781867 0 0;0.489431491564531 0 0;0.493482522347195 0 0;0.49753355312986 0 0;0.501584583912524 0 0;0.505635614695189 0 0;0.509686645477853 0 0;0.513737676260517 0 0;0.517788707043181 0 0;0.521839737825846 0 0;0.52589076860851 0 0;0.529941799391174 0 0;0.533992830173839 0 0;0.538043860956503 0 0;0.542094891739167 0 0;0.546145922521832 0 0;0.550196953304496 0 0;0.55424798408716 0 0;0.558299014869825 0 0;0.562350045652489 0 0;0.566401076435153 0 0;0.570452107217818 0 0;0.574503138000482 0 0;0.578554168783146 0 0;0.582605199565811 0 0;0.586656230348475 0 0;0.59070726113114 0 0;0.594758291913804 0 0;0.598809322696469 0 0;0.602860353479133 0 0;0.606911384261798 0 0;0.610962415044462 0 0;0.615013445827126 0 0;0.619064476609791 0 0;0.623115507392455 0 0;0.62716653817512 0 0;0.631217568957784 0 0;0.635268599740449 0 0;0.639319630523113 0 0;0.643370661305777 0 0;0.647421692088442 0 0;0.651472722871106 0 0;0.655523753653771 0 0;0.659574784436435 0 0;0.6636258152191 0 0;0.667676846001764 0 0;0.671727876784428 0 0;0.675778907567093 0 0;0.679829938349757 0 0;0.683880969132422 0 0;0.687931999915086 0 0;0.691983030697751 0 0;0.696034061480415 0 0;0.70008509226308 0 0;0.704136123045744 0 0;0.708187153828408 0 0;0.712238184611073 0 0;0.716289215393737 0 0;0.720340246176402 0 0;0.724391276959066 0 0;0.728442307741731 0 0;0.732493338524395 0 0;0.736544369307059 0 0;0.740595400089724 0 0;0.744646430872388 0 0;0.748697461655053 0 0;0.752748492437717 0 0;0.756799523220381 0 0;0.760850554003046 0 0;0.76490158478571 0 0;0.768952615568375 0 0;0.773003646351039 0 0;0.777054677133704 0 0;0.781105707916368 0 0;0.785156738699033 0 0;0.789207769481697 0 0;0.793258800264361 0 0;0.797309831047026 0 0;0.80136086182969 0 0;0.805411892612355 0 0;0.809462923395019 0 0;0.813513954177684 0 0;0.817564984960348 0 0;0.821616015743012 0 0;0.825667046525677 0 0;0.829718077308341 0 0;0.833769108091006 0 0;0.83782013887367 0 0;0.841871169656334 0 0;0.845922200438999 0 0;0.849973231221663 0 0;0.854024262004328 0 0;0.858075292786992 0 0;0.862126323569656 0 0;0.866177354352321 0 0;0.870228385134985 0 0;0.874279415917649 0 0;0.878330446700314 0 0;0.882381477482978 0 0;0.886432508265642 0 0;0.890483539048307 0 0;0.894534569830971 0 0;0.898585600613636 0 0;0.9026366313963 0 0;0.906687662178964 0 0;0.910738692961629 0 0;0.914789723744293 0 0;0.918840754526957 0 0;0.922891785309622 0 0;0.926942816092286 0 0;0.930993846874951 0 0;0.935044877657615 0 0;0.939095908440279 0 0;0.943146939222944 0 0;0.947197970005608 0 0;0.951249000788272 0 0;0.955300031570937 0 0;0.959351062353601 0 0;0.963402093136266 0 0;0.96745312391893 0 0;0.971504154701594 0 0;0.975555185484259 0 0;0.979606216266923 0 0;0.983657247049588 0 0;0.987708277832252 0 0;0.991759308614916 0 0;0.995806899951635 3.43944594599642e-06 0;0.998789593369118 0.00107177681112655 0;0.999865498621048 0.00404690234186127 0;0.99999802076514 0.00796541098043363 0;1 0.0120144625282381 0;1 0.0160654933109025 0;1 0.0201165240935669 0;1 0.0241675548762312 0;1 0.0282185856588956 0;1 0.03226961644156 0;1 0.0363206472242244 0;1 0.0403716780068887 0;1 0.0444227087895531 0;1 0.0484737395722175 0;1 0.0525247703548819 0;1 0.0565758011375462 0;1 0.0606268319202106 0;1 0.064677862702875 0;1 0.0687288934855394 0;1 0.0727799242682037 0;1 0.0768309550508681 0;1 0.0808819858335325 0;1 0.0849330166161969 0;1 0.0889840473988612 0;1 0.0930350781815256 0;1 0.09708610896419 0;1 0.101137139746854 0;1 0.105188170529519 0;1 0.109239201312183 0;1 0.113290232094847 0;1 0.117341262877512 0;1 0.121392293660176 0;1 0.125443324442841 0;1 0.129494355225505 0;1 0.133545386008169 0;1 0.137596416790834 0;1 0.141647447573498 0;1 0.145698478356162 0;1 0.149749509138827 0;1 0.153800539921491 0;1 0.157851570704155 0;1 0.16190260148682 0;1 0.165953632269484 0;1 0.170004663052149 0;1 0.174055693834813 0;1 0.178106724617477 0;1 0.182157755400142 0;1 0.186208786182806 0;1 0.19025981696547 0;1 0.194310847748135 0;1 0.198361878530799 0;1 0.202412909313464 0;1 0.206463940096128 0;1 0.210514970878792 0;1 0.214566001661457 0;1 0.218617032444121 0;1 0.222668063226785 0;1 0.22671909400945 0;1 0.230770124792114 0;1 0.234821155574779 0;1 0.238872186357443 0;1 0.242923217140107 0;1 0.246974247922772 0;1 0.251025278705436 0;1 0.2550763094881 0;1 0.259127340270765 0;1 0.263178371053429 0;1 0.267229401836094 0;1 0.271280432618758 0;1 0.275331463401422 0;1 0.279382494184087 0;1 0.283433524966751 0;1 0.287484555749415 0;1 0.29153558653208 0;1 0.295586617314744 0;1 0.299637648097408 0;1 0.303688678880073 0;1 0.307739709662737 0;1 0.311790740445401 0;1 0.315841771228065 0;1 0.31989280201073 0;1 0.323943832793394 0;1 0.327994863576058 0;1 0.332045894358722 0;1 0.336096925141387 0;1 0.340147955924051 0;1 0.344198986706715 0;1 0.348250017489379 0;1 0.352301048272044 0;1 0.356352079054708 0;1 0.360403109837372 0;1 0.364454140620036 0;1 0.368505171402701 0;1 0.372556202185365 0;1 0.376607232968029 0;1 0.380658263750694 0;1 0.384709294533358 0;1 0.388760325316022 0;1 0.392811356098686 0;1 0.396862386881351 0;1 0.400913417664015 0;1 0.404964448446679 0;1 0.409015479229343 0;1 0.413066510012008 0;1 0.417117540794672 0;1 0.421168571577336 0;1 0.42521960236 0;1 0.429270633142665 0;1 0.433321663925329 0;1 0.437372694707993 0;1 0.441423725490657 0;1 0.445474756273322 0;1 0.449525787055986 0;1 0.45357681783865 0;1 0.457627848621314 0;1 0.461678879403979 0;1 0.465729910186643 0;1 0.469780940969307 0;1 0.473831971751971 0;1 0.477883002534636 0;1 0.4819340333173 0;1 0.485985064099964 0;1 0.490036094882628 0;1 0.494087125665293 0;1 0.498138156447957 0;1 0.502189187230621 0;1 0.506240218013285 0;1 0.51029124879595 0;1 0.514342279578614 0;1 0.518393310361278 0;1 0.522444341143942 0;1 0.526495371926607 0;1 0.530546402709271 0;1 0.534597433491935 0;1 0.5386484642746 0;1 0.542699495057264 0;1 0.546750525839928 0;1 0.550801556622592 0;1 0.554852587405257 0;1 0.558903618187921 0;1 0.562954648970585 0;1 0.567005679753249 0;1 0.571056710535913 0;1 0.575107741318578 0;1 0.579158772101242 0;1 0.583209802883906 0;1 0.587260833666571 0;1 0.591311864449235 0;1 0.595362895231899 0;1 0.599413926014563 0;1 0.603464956797228 0;1 0.607515987579892 0;1 0.611567018362556 0;1 0.61561804914522 0;1 0.619669079927885 0;1 0.623720110710549 0;1 0.627771141493213 0;1 0.631822172275877 0;1 0.635873203058542 0;1 0.639924233841206 0;1 0.64397526462387 0;1 0.648026295406534 0;1 0.652077326189199 0;1 0.656128356971863 0;1 0.660179387754527 0;1 0.664230418537191 0;1 0.668281449319856 0;1 0.67233248010252 0;1 0.676383510885184 0;1 0.680434541667849 0;1 0.684485572450513 0;1 0.688536603233177 0;1 0.692587634015841 0;1 0.696638664798506 0;1 0.70068969558117 0;1 0.704740726363834 0;1 0.708791757146498 0;1 0.713023839584252 0;1 0.716653820006239 0;1 0.720283800428227 0;1 0.723913780850214 0;1 0.727543761272201 0;1 0.731173741694188 0;1 0.734803722116176 0;1 0.738433702538163 0;1 0.74206368296015 0;1 0.745693663382137 0;1 0.749323643804125 0;1 0.752953624226112 0;1 0.756583604648099 0;1 0.760213585070086 0;1 0.763843565492073 0;1 0.767473545914061 0;1 0.771103526336048 0;1 0.774733506758035 0;1 0.778363487180022 0;1 0.78199346760201 0;1 0.785623448023997 0;1 0.789253428445984 0;1 0.792883408867971 0;1 0.796513389289959 0;1 0.800143369711946 0;1 0.803773350133933 0;1 0.80740333055592 0;1 0.811033310977908 0;1 0.814663291399895 0;1 0.818293271821882 0;1 0.821923252243869 0;1 0.825553232665856 0;1 0.829183213087844 0;1 0.832813193509831 0;1 0.836443173931818 0;1 0.840073154353805 0;1 0.843703134775793 0;1 0.84733311519778 0;1 0.850963095619767 0;1 0.854593076041754 0;1 0.858223056463742 0;1 0.861853036885729 0;1 0.865483017307716 0;1 0.869112997729703 0;1 0.872742978151691 0;1 0.876372958573678 0;1 0.880002938995665 0;1 0.883632919417652 0;1 0.887262899839639 0;1 0.890892880261627 0;1 0.894522860683614 0;1 0.898152841105601 0;1 0.901782821527588 0;1 0.905412801949576 0;1 0.909042782371563 0;1 0.91267276279355 0;1 0.916302743215537 0;1 0.919932723637525 0;1 0.923562704059512 0;1 0.927192684481499 0;1 0.930822664903486 0;1 0.934452645325474 0;1 0.938082625747461 0;1 0.941712606169448 0;1 0.945342586591435 0;1 0.948972567013423 0;1 0.95260254743541 0;1 0.956232527857397 0;1 0.959862508279384 0;1 0.963492488701371 0;1 0.967122469123359 0;1 0.970752449545346 0;1 0.974382429967333 0;1 0.97801241038932 0;1 0.981642390811308 0;1 0.985272371233295 0;1 0.988902351655282 0;1 0.992532218487635 1.7038445099368e-07;1 0.996157817343127 6.74273419432007e-06;1 0.999439815419274 0.000528716252954609;1 0.999997903876187 0.00513655420056591;1 0.999999949287327 0.0105784567168368;1 1 0.0160233512808084;1 1 0.0214683219137892;1 1 0.0269132925467701;1 1 0.0323582631797509;1 1 0.0378032338127318;1 1 0.0432482044457126;1 1 0.0486931750786935;1 1 0.0541381457116744;1 1 0.0595831163446552;1 1 0.0650280869776361;1 1 0.0704730576106169;1 1 0.0759180282435978;1 1 0.0813629988765786;1 1 0.0868079695095595;1 1 0.0922529401425403;1 1 0.0976979107755212;1 1 0.103142881408502;1 1 0.108587852041483;1 1 0.114032822674464;1 1 0.119477793307445;1 1 0.124922763940425;1 1 0.130367734573406;1 1 0.135812705206387;1 1 0.141257675839368;1 1 0.146702646472349;1 1 0.15214761710533;1 1 0.157592587738311;1 1 0.163037558371291;1 1 0.168482529004272;1 1 0.173927499637253;1 1 0.179372470270234;1 1 0.184817440903215;1 1 0.190262411536196;1 1 0.195707382169177;1 1 0.201152352802157;1 1 0.206597323435138;1 1 0.212042294068119;1 1 0.2174872647011;1 1 0.222932235334081;1 1 0.228377205967062;1 1 0.233822176600043;1 1 0.239267147233023;1 1 0.244712117866004;1 1 0.250157088498985;1 1 0.255602059131966;1 1 0.261047029764947;1 1 0.266492000397928;1 1 0.271936971030909;1 1 0.277381941663889;1 1 0.28282691229687;1 1 0.288271882929851;1 1 0.293716853562832;1 1 0.299161824195813;1 1 0.304606794828794;1 1 0.310051765461775;1 1 0.315496736094755;1 1 0.320941706727736;1 1 0.326386677360717;1 1 0.331831647993698;1 1 0.337276618626679;1 1 0.34272158925966;1 1 0.348166559892641;1 1 0.353611530525621;1 1 0.359056501158602;1 1 0.364501471791583;1 1 0.369946442424564;1 1 0.375391413057545;1 1 0.380836383690526;1 1 0.386281354323507;1 1 0.391726324956487;1 1 0.397171295589468;1 1 0.402616266222449;1 1 0.40806123685543;1 1 0.413506207488411;1 1 0.418951178121391;1 1 0.424396148754372;1 1 0.429841119387353;1 1 0.435286090020334;1 1 0.440731060653315;1 1 0.446176031286296;1 1 0.451621001919276;1 1 0.457065972552257;1 1 0.462510943185238;1 1 0.467955913818219;1 1 0.4734008844512;1 1 0.478845855084181;1 1 0.484290825717162;1 1 0.489735796350143;1 1 0.495180766983124;1 1 0.500625737616106;1 1 0.506070708249087;1 1 0.511515678882068;1 1 0.516960649515049;1 1 0.52240562014803;1 1 0.527850590781012;1 1 0.533295561413993;1 1 0.538740532046974;1 1 0.544185502679955;1 1 0.549630473312936;1 1 0.555075443945917;1 1 0.560520414578899;1 1 0.56596538521188;1 1 0.571410355844861;1 1 0.576855326477842;1 1 0.582300297110823;1 1 0.587745267743804;1 1 0.593190238376786;1 1 0.598635209009767;1 1 0.604080179642748;1 1 0.609525150275729;1 1 0.61497012090871;1 1 0.620415091541691;1 1 0.625860062174673;1 1 0.631305032807654;1 1 0.636750003440635;1 1 0.642194974073616;1 1 0.647639944706597;1 1 0.653084915339579;1 1 0.658504314154768;1 1 0.664186626681104;1 1 0.67007808937091;1 1 0.675969552060716;1 1 0.681861014750521;1 1 0.687752477440327;1 1 0.693643940130133;1 1 0.699535402819939;1 1 0.705426865509745;1 1 0.711318328199551;1 1 0.717209790889357;1 1 0.723101253579163;1 1 0.728992716268969;1 1 0.734884178958775;1 1 0.740775641648581;1 1 0.746667104338387;1 1 0.752558567028193;1 1 0.758450029717999;1 1 0.764341492407805;1 1 0.770232955097611;1 1 0.776124417787416;1 1 0.782015880477222;1 1 0.787907343167028;1 1 0.793798805856834;1 1 0.79969026854664;1 1 0.805581731236446;1 1 0.811473193926252;1 1 0.817364656616058;1 1 0.823256119305864;1 1 0.82914758199567;1 1 0.835039044685476;1 1 0.840930507375282;1 1 0.846821970065088;1 1 0.852713432754894;1 1 0.8586048954447;1 1 0.864496358134506;1 1 0.870387820824312;1 1 0.876279283514118;1 1 0.882170746203923;1 1 0.888062208893729;1 1 0.893953671583535;1 1 0.899845134273341;1 1 0.905736596963147;1 1 0.911628059652953;1 1 0.917519522342759;1 1 0.923410985032565;1 1 0.929302447722371;1 1 0.935193910412177;1 1 0.941085373101983;1 1 0.946976835791789;1 1 0.952868298481595;1 1 0.958759761171401;1 1 0.964651223861207;1 1 0.970542686551013;1 1 0.976434149240818;1 1 0.982325611930624;1 1 0.98821707462043;1 1 0.994108537310233;1 1 0.999999999999974])
    annotation('rectangle',...
    [0.829166666666665 0.0458253968253974 0.0416666666666672 0.0383015873015867],...
    'FaceColor',[0.149019607843137 0.149019607843137 0.149019607843137]);
    annotation('textbox',...
    [0.869047619047619 0.022809523809524 0.0875000000000002 0.0650793650793651],...
    'String',{'NaN'},...
    'LineStyle','none',...
    'Interpreter','latex',...
    'FitBoxToText','off');
        
    figure;
        h = pcolor(1:13, (0:5:175), eyeball_sdep_H);%, 50, 'linecolor', 'none');
        shading flat;
        colormap('Hot(1200)')
        set(h,'alphadata',~isnan(eyeball_sdep_H))
        set(gca,'color',[0.15,0.15,0.15]) 
        xticks([1:12] + 0.5)
        yticks([0:10:180])
        yticklabels([0:10:90 80:-10:0])
        xticklabels({'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'})
        xlabel('Month')
        ylabel('Solar depression angle [degrees]')
        title('Solar depression angle. H-band. Time increasing upwards.')
        colorbar;
            %%
    set(gca,'color',[0.149019607843137 0.149019607843137 0.149019607843137], 'colormap',...
    [0.331441291040623 0 0;0.335492321823287 0 0;0.339543352605952 0 0;0.343594383388616 0 0;0.34764541417128 0 0;0.351696444953945 0 0;0.355747475736609 0 0;0.359798506519273 0 0;0.363849537301938 0 0;0.367900568084602 0 0;0.371951598867266 0 0;0.376002629649931 0 0;0.380053660432595 0 0;0.384104691215259 0 0;0.388155721997923 0 0;0.392206752780588 0 0;0.396257783563252 0 0;0.400308814345916 0 0;0.404359845128581 0 0;0.408410875911245 0 0;0.412461906693909 0 0;0.416512937476574 0 0;0.420563968259238 0 0;0.424614999041902 0 0;0.428666029824567 0 0;0.432717060607231 0 0;0.436768091389895 0 0;0.440819122172559 0 0;0.444870152955224 0 0;0.448921183737888 0 0;0.452972214520552 0 0;0.457023245303217 0 0;0.461074276085881 0 0;0.465125306868545 0 0;0.46917633765121 0 0;0.473227368433874 0 0;0.477278399216538 0 0;0.481329429999203 0 0;0.485380460781867 0 0;0.489431491564531 0 0;0.493482522347195 0 0;0.49753355312986 0 0;0.501584583912524 0 0;0.505635614695189 0 0;0.509686645477853 0 0;0.513737676260517 0 0;0.517788707043181 0 0;0.521839737825846 0 0;0.52589076860851 0 0;0.529941799391174 0 0;0.533992830173839 0 0;0.538043860956503 0 0;0.542094891739167 0 0;0.546145922521832 0 0;0.550196953304496 0 0;0.55424798408716 0 0;0.558299014869825 0 0;0.562350045652489 0 0;0.566401076435153 0 0;0.570452107217818 0 0;0.574503138000482 0 0;0.578554168783146 0 0;0.582605199565811 0 0;0.586656230348475 0 0;0.59070726113114 0 0;0.594758291913804 0 0;0.598809322696469 0 0;0.602860353479133 0 0;0.606911384261798 0 0;0.610962415044462 0 0;0.615013445827126 0 0;0.619064476609791 0 0;0.623115507392455 0 0;0.62716653817512 0 0;0.631217568957784 0 0;0.635268599740449 0 0;0.639319630523113 0 0;0.643370661305777 0 0;0.647421692088442 0 0;0.651472722871106 0 0;0.655523753653771 0 0;0.659574784436435 0 0;0.6636258152191 0 0;0.667676846001764 0 0;0.671727876784428 0 0;0.675778907567093 0 0;0.679829938349757 0 0;0.683880969132422 0 0;0.687931999915086 0 0;0.691983030697751 0 0;0.696034061480415 0 0;0.70008509226308 0 0;0.704136123045744 0 0;0.708187153828408 0 0;0.712238184611073 0 0;0.716289215393737 0 0;0.720340246176402 0 0;0.724391276959066 0 0;0.728442307741731 0 0;0.732493338524395 0 0;0.736544369307059 0 0;0.740595400089724 0 0;0.744646430872388 0 0;0.748697461655053 0 0;0.752748492437717 0 0;0.756799523220381 0 0;0.760850554003046 0 0;0.76490158478571 0 0;0.768952615568375 0 0;0.773003646351039 0 0;0.777054677133704 0 0;0.781105707916368 0 0;0.785156738699033 0 0;0.789207769481697 0 0;0.793258800264361 0 0;0.797309831047026 0 0;0.80136086182969 0 0;0.805411892612355 0 0;0.809462923395019 0 0;0.813513954177684 0 0;0.817564984960348 0 0;0.821616015743012 0 0;0.825667046525677 0 0;0.829718077308341 0 0;0.833769108091006 0 0;0.83782013887367 0 0;0.841871169656334 0 0;0.845922200438999 0 0;0.849973231221663 0 0;0.854024262004328 0 0;0.858075292786992 0 0;0.862126323569656 0 0;0.866177354352321 0 0;0.870228385134985 0 0;0.874279415917649 0 0;0.878330446700314 0 0;0.882381477482978 0 0;0.886432508265642 0 0;0.890483539048307 0 0;0.894534569830971 0 0;0.898585600613636 0 0;0.9026366313963 0 0;0.906687662178964 0 0;0.910738692961629 0 0;0.914789723744293 0 0;0.918840754526957 0 0;0.922891785309622 0 0;0.926942816092286 0 0;0.930993846874951 0 0;0.935044877657615 0 0;0.939095908440279 0 0;0.943146939222944 0 0;0.947197970005608 0 0;0.951249000788272 0 0;0.955300031570937 0 0;0.959351062353601 0 0;0.963402093136266 0 0;0.96745312391893 0 0;0.971504154701594 0 0;0.975555185484259 0 0;0.979606216266923 0 0;0.983657247049588 0 0;0.987708277832252 0 0;0.991759308614916 0 0;0.995806899951635 3.43944594599642e-06 0;0.998789593369118 0.00107177681112655 0;0.999865498621048 0.00404690234186127 0;0.99999802076514 0.00796541098043363 0;1 0.0120144625282381 0;1 0.0160654933109025 0;1 0.0201165240935669 0;1 0.0241675548762312 0;1 0.0282185856588956 0;1 0.03226961644156 0;1 0.0363206472242244 0;1 0.0403716780068887 0;1 0.0444227087895531 0;1 0.0484737395722175 0;1 0.0525247703548819 0;1 0.0565758011375462 0;1 0.0606268319202106 0;1 0.064677862702875 0;1 0.0687288934855394 0;1 0.0727799242682037 0;1 0.0768309550508681 0;1 0.0808819858335325 0;1 0.0849330166161969 0;1 0.0889840473988612 0;1 0.0930350781815256 0;1 0.09708610896419 0;1 0.101137139746854 0;1 0.105188170529519 0;1 0.109239201312183 0;1 0.113290232094847 0;1 0.117341262877512 0;1 0.121392293660176 0;1 0.125443324442841 0;1 0.129494355225505 0;1 0.133545386008169 0;1 0.137596416790834 0;1 0.141647447573498 0;1 0.145698478356162 0;1 0.149749509138827 0;1 0.153800539921491 0;1 0.157851570704155 0;1 0.16190260148682 0;1 0.165953632269484 0;1 0.170004663052149 0;1 0.174055693834813 0;1 0.178106724617477 0;1 0.182157755400142 0;1 0.186208786182806 0;1 0.19025981696547 0;1 0.194310847748135 0;1 0.198361878530799 0;1 0.202412909313464 0;1 0.206463940096128 0;1 0.210514970878792 0;1 0.214566001661457 0;1 0.218617032444121 0;1 0.222668063226785 0;1 0.22671909400945 0;1 0.230770124792114 0;1 0.234821155574779 0;1 0.238872186357443 0;1 0.242923217140107 0;1 0.246974247922772 0;1 0.251025278705436 0;1 0.2550763094881 0;1 0.259127340270765 0;1 0.263178371053429 0;1 0.267229401836094 0;1 0.271280432618758 0;1 0.275331463401422 0;1 0.279382494184087 0;1 0.283433524966751 0;1 0.287484555749415 0;1 0.29153558653208 0;1 0.295586617314744 0;1 0.299637648097408 0;1 0.303688678880073 0;1 0.307739709662737 0;1 0.311790740445401 0;1 0.315841771228065 0;1 0.31989280201073 0;1 0.323943832793394 0;1 0.327994863576058 0;1 0.332045894358722 0;1 0.336096925141387 0;1 0.340147955924051 0;1 0.344198986706715 0;1 0.348250017489379 0;1 0.352301048272044 0;1 0.356352079054708 0;1 0.360403109837372 0;1 0.364454140620036 0;1 0.368505171402701 0;1 0.372556202185365 0;1 0.376607232968029 0;1 0.380658263750694 0;1 0.384709294533358 0;1 0.388760325316022 0;1 0.392811356098686 0;1 0.396862386881351 0;1 0.400913417664015 0;1 0.404964448446679 0;1 0.409015479229343 0;1 0.413066510012008 0;1 0.417117540794672 0;1 0.421168571577336 0;1 0.42521960236 0;1 0.429270633142665 0;1 0.433321663925329 0;1 0.437372694707993 0;1 0.441423725490657 0;1 0.445474756273322 0;1 0.449525787055986 0;1 0.45357681783865 0;1 0.457627848621314 0;1 0.461678879403979 0;1 0.465729910186643 0;1 0.469780940969307 0;1 0.473831971751971 0;1 0.477883002534636 0;1 0.4819340333173 0;1 0.485985064099964 0;1 0.490036094882628 0;1 0.494087125665293 0;1 0.498138156447957 0;1 0.502189187230621 0;1 0.506240218013285 0;1 0.51029124879595 0;1 0.514342279578614 0;1 0.518393310361278 0;1 0.522444341143942 0;1 0.526495371926607 0;1 0.530546402709271 0;1 0.534597433491935 0;1 0.5386484642746 0;1 0.542699495057264 0;1 0.546750525839928 0;1 0.550801556622592 0;1 0.554852587405257 0;1 0.558903618187921 0;1 0.562954648970585 0;1 0.567005679753249 0;1 0.571056710535913 0;1 0.575107741318578 0;1 0.579158772101242 0;1 0.583209802883906 0;1 0.587260833666571 0;1 0.591311864449235 0;1 0.595362895231899 0;1 0.599413926014563 0;1 0.603464956797228 0;1 0.607515987579892 0;1 0.611567018362556 0;1 0.61561804914522 0;1 0.619669079927885 0;1 0.623720110710549 0;1 0.627771141493213 0;1 0.631822172275877 0;1 0.635873203058542 0;1 0.639924233841206 0;1 0.64397526462387 0;1 0.648026295406534 0;1 0.652077326189199 0;1 0.656128356971863 0;1 0.660179387754527 0;1 0.664230418537191 0;1 0.668281449319856 0;1 0.67233248010252 0;1 0.676383510885184 0;1 0.680434541667849 0;1 0.684485572450513 0;1 0.688536603233177 0;1 0.692587634015841 0;1 0.696638664798506 0;1 0.70068969558117 0;1 0.704740726363834 0;1 0.708791757146498 0;1 0.713023839584252 0;1 0.716653820006239 0;1 0.720283800428227 0;1 0.723913780850214 0;1 0.727543761272201 0;1 0.731173741694188 0;1 0.734803722116176 0;1 0.738433702538163 0;1 0.74206368296015 0;1 0.745693663382137 0;1 0.749323643804125 0;1 0.752953624226112 0;1 0.756583604648099 0;1 0.760213585070086 0;1 0.763843565492073 0;1 0.767473545914061 0;1 0.771103526336048 0;1 0.774733506758035 0;1 0.778363487180022 0;1 0.78199346760201 0;1 0.785623448023997 0;1 0.789253428445984 0;1 0.792883408867971 0;1 0.796513389289959 0;1 0.800143369711946 0;1 0.803773350133933 0;1 0.80740333055592 0;1 0.811033310977908 0;1 0.814663291399895 0;1 0.818293271821882 0;1 0.821923252243869 0;1 0.825553232665856 0;1 0.829183213087844 0;1 0.832813193509831 0;1 0.836443173931818 0;1 0.840073154353805 0;1 0.843703134775793 0;1 0.84733311519778 0;1 0.850963095619767 0;1 0.854593076041754 0;1 0.858223056463742 0;1 0.861853036885729 0;1 0.865483017307716 0;1 0.869112997729703 0;1 0.872742978151691 0;1 0.876372958573678 0;1 0.880002938995665 0;1 0.883632919417652 0;1 0.887262899839639 0;1 0.890892880261627 0;1 0.894522860683614 0;1 0.898152841105601 0;1 0.901782821527588 0;1 0.905412801949576 0;1 0.909042782371563 0;1 0.91267276279355 0;1 0.916302743215537 0;1 0.919932723637525 0;1 0.923562704059512 0;1 0.927192684481499 0;1 0.930822664903486 0;1 0.934452645325474 0;1 0.938082625747461 0;1 0.941712606169448 0;1 0.945342586591435 0;1 0.948972567013423 0;1 0.95260254743541 0;1 0.956232527857397 0;1 0.959862508279384 0;1 0.963492488701371 0;1 0.967122469123359 0;1 0.970752449545346 0;1 0.974382429967333 0;1 0.97801241038932 0;1 0.981642390811308 0;1 0.985272371233295 0;1 0.988902351655282 0;1 0.992532218487635 1.7038445099368e-07;1 0.996157817343127 6.74273419432007e-06;1 0.999439815419274 0.000528716252954609;1 0.999997903876187 0.00513655420056591;1 0.999999949287327 0.0105784567168368;1 1 0.0160233512808084;1 1 0.0214683219137892;1 1 0.0269132925467701;1 1 0.0323582631797509;1 1 0.0378032338127318;1 1 0.0432482044457126;1 1 0.0486931750786935;1 1 0.0541381457116744;1 1 0.0595831163446552;1 1 0.0650280869776361;1 1 0.0704730576106169;1 1 0.0759180282435978;1 1 0.0813629988765786;1 1 0.0868079695095595;1 1 0.0922529401425403;1 1 0.0976979107755212;1 1 0.103142881408502;1 1 0.108587852041483;1 1 0.114032822674464;1 1 0.119477793307445;1 1 0.124922763940425;1 1 0.130367734573406;1 1 0.135812705206387;1 1 0.141257675839368;1 1 0.146702646472349;1 1 0.15214761710533;1 1 0.157592587738311;1 1 0.163037558371291;1 1 0.168482529004272;1 1 0.173927499637253;1 1 0.179372470270234;1 1 0.184817440903215;1 1 0.190262411536196;1 1 0.195707382169177;1 1 0.201152352802157;1 1 0.206597323435138;1 1 0.212042294068119;1 1 0.2174872647011;1 1 0.222932235334081;1 1 0.228377205967062;1 1 0.233822176600043;1 1 0.239267147233023;1 1 0.244712117866004;1 1 0.250157088498985;1 1 0.255602059131966;1 1 0.261047029764947;1 1 0.266492000397928;1 1 0.271936971030909;1 1 0.277381941663889;1 1 0.28282691229687;1 1 0.288271882929851;1 1 0.293716853562832;1 1 0.299161824195813;1 1 0.304606794828794;1 1 0.310051765461775;1 1 0.315496736094755;1 1 0.320941706727736;1 1 0.326386677360717;1 1 0.331831647993698;1 1 0.337276618626679;1 1 0.34272158925966;1 1 0.348166559892641;1 1 0.353611530525621;1 1 0.359056501158602;1 1 0.364501471791583;1 1 0.369946442424564;1 1 0.375391413057545;1 1 0.380836383690526;1 1 0.386281354323507;1 1 0.391726324956487;1 1 0.397171295589468;1 1 0.402616266222449;1 1 0.40806123685543;1 1 0.413506207488411;1 1 0.418951178121391;1 1 0.424396148754372;1 1 0.429841119387353;1 1 0.435286090020334;1 1 0.440731060653315;1 1 0.446176031286296;1 1 0.451621001919276;1 1 0.457065972552257;1 1 0.462510943185238;1 1 0.467955913818219;1 1 0.4734008844512;1 1 0.478845855084181;1 1 0.484290825717162;1 1 0.489735796350143;1 1 0.495180766983124;1 1 0.500625737616106;1 1 0.506070708249087;1 1 0.511515678882068;1 1 0.516960649515049;1 1 0.52240562014803;1 1 0.527850590781012;1 1 0.533295561413993;1 1 0.538740532046974;1 1 0.544185502679955;1 1 0.549630473312936;1 1 0.555075443945917;1 1 0.560520414578899;1 1 0.56596538521188;1 1 0.571410355844861;1 1 0.576855326477842;1 1 0.582300297110823;1 1 0.587745267743804;1 1 0.593190238376786;1 1 0.598635209009767;1 1 0.604080179642748;1 1 0.609525150275729;1 1 0.61497012090871;1 1 0.620415091541691;1 1 0.625860062174673;1 1 0.631305032807654;1 1 0.636750003440635;1 1 0.642194974073616;1 1 0.647639944706597;1 1 0.653084915339579;1 1 0.658504314154768;1 1 0.664186626681104;1 1 0.67007808937091;1 1 0.675969552060716;1 1 0.681861014750521;1 1 0.687752477440327;1 1 0.693643940130133;1 1 0.699535402819939;1 1 0.705426865509745;1 1 0.711318328199551;1 1 0.717209790889357;1 1 0.723101253579163;1 1 0.728992716268969;1 1 0.734884178958775;1 1 0.740775641648581;1 1 0.746667104338387;1 1 0.752558567028193;1 1 0.758450029717999;1 1 0.764341492407805;1 1 0.770232955097611;1 1 0.776124417787416;1 1 0.782015880477222;1 1 0.787907343167028;1 1 0.793798805856834;1 1 0.79969026854664;1 1 0.805581731236446;1 1 0.811473193926252;1 1 0.817364656616058;1 1 0.823256119305864;1 1 0.82914758199567;1 1 0.835039044685476;1 1 0.840930507375282;1 1 0.846821970065088;1 1 0.852713432754894;1 1 0.8586048954447;1 1 0.864496358134506;1 1 0.870387820824312;1 1 0.876279283514118;1 1 0.882170746203923;1 1 0.888062208893729;1 1 0.893953671583535;1 1 0.899845134273341;1 1 0.905736596963147;1 1 0.911628059652953;1 1 0.917519522342759;1 1 0.923410985032565;1 1 0.929302447722371;1 1 0.935193910412177;1 1 0.941085373101983;1 1 0.946976835791789;1 1 0.952868298481595;1 1 0.958759761171401;1 1 0.964651223861207;1 1 0.970542686551013;1 1 0.976434149240818;1 1 0.982325611930624;1 1 0.98821707462043;1 1 0.994108537310233;1 1 0.999999999999974])
    annotation('rectangle',...
    [0.829166666666665 0.0458253968253974 0.0416666666666672 0.0383015873015867],...
    'FaceColor',[0.149019607843137 0.149019607843137 0.149019607843137]);
    annotation('textbox',...
    [0.869047619047619 0.022809523809524 0.0875000000000002 0.0650793650793651],...
    'String',{'NaN'},...
    'LineStyle','none',...
    'Interpreter','latex',...
    'FitBoxToText','off');



                
                
                
                